@@ -1,4 +1,4 @@
-"""
+"""This module defines the internals to map the spatial functions to the spatial columns.
 
 This module defines the :class:`GenericFunction` class, which is the base for
 the implementation of spatial functions in GeoAlchemy.  This module is also
@@ -84,8 +84,10 @@ try:
     from sqlalchemy.util import with_metaclass
 
     class _GeoGenericMeta(_GenericMeta):
-        """Extend the metaclass mechanism of sqlalchemy to register the functions in
-        a specific registry for geoalchemy2"""
+        """Extend the registering mechanism of sqlalchemy.
+
+        The spatial functions are registered in a specific registry for geoalchemy2.
+        """
 
         _register = False
 
@@ -123,7 +125,6 @@ except ImportError:
 
 
 class TableRowElement(ColumnElement):
-
     inherit_cache = False
     """The cache is disabled for this class."""
 
@@ -136,15 +137,17 @@ class TableRowElement(ColumnElement):
 
 
 class ST_AsGeoJSON(_GeoFunctionBase):
-    """Special process for the ST_AsGeoJSON() function to be able to work with its
-    feature version introduced in PostGIS 3."""
+    """Special process for the ST_AsGeoJSON() function.
+
+    This is to be able to work with its feature version introduced in PostGIS 3.
+    """
 
     name = "ST_AsGeoJSON"
     inherit_cache = True
     """The cache is enabled for this class."""
 
     def __init__(self, *args, **kwargs):
-        expr = kwargs.pop('expr', None)
+        expr = kwargs.pop("expr", None)
         args = list(args)
         if expr is not None:
             args = [expr] + args
@@ -172,9 +175,10 @@ class ST_AsGeoJSON(_GeoFunctionBase):
     __doc__ = (
         'Return the geometry as a GeoJSON "geometry" object, or the row as a '
         'GeoJSON feature" object (PostGIS 3 only). (Cf GeoJSON specifications RFC '
-        '7946). 2D and 3D Geometries are both supported. GeoJSON only support SFS '
-        '1.1 geometry types (no curve support for example). '
-        'See https://postgis.net/docs/ST_AsGeoJSON.html')
+        "7946). 2D and 3D Geometries are both supported. GeoJSON only support SFS "
+        "1.1 geometry types (no curve support for example). "
+        "See https://postgis.net/docs/ST_AsGeoJSON.html"
+    )
 
 
 @compiles(TableRowElement)
@@ -201,8 +205,7 @@ def _compile_table_row_thing(element, compiler, **kw):
 
 
 class GenericFunction(_GeoFunctionBase):
-    """
-    The base class for GeoAlchemy functions.
+    """The base class for GeoAlchemy functions.
 
     This class inherits from ``sqlalchemy.sql.functions.GenericFunction``, so
     functions defined by subclassing this class can be given a fixed return
@@ -233,7 +236,7 @@ class GenericFunction(_GeoFunctionBase):
     _register = False
 
     def __init__(self, *args, **kwargs):
-        expr = kwargs.pop('expr', None)
+        expr = kwargs.pop("expr", None)
         args = list(args)
         if expr is not None:
             args = [expr] + args
@@ -252,74 +255,25 @@ class GenericFunction(_GeoFunctionBase):
 # Iterate through _FUNCTIONS and create GenericFunction classes dynamically
 for name, type_, doc in _FUNCTIONS:
     attributes = {
-        'name': name,
-        'inherit_cache': True,
+        "name": name,
+        "inherit_cache": True,
     }
     docs = []
 
     if isinstance(doc, tuple):
         docs.append(doc[0])
-        docs.append('see http://postgis.net/docs/{0}.html'.format(doc[1]))
+        docs.append("see http://postgis.net/docs/{0}.html".format(doc[1]))
     elif doc is not None:
         docs.append(doc)
-        docs.append('see http://postgis.net/docs/{0}.html'.format(name))
+        docs.append("see http://postgis.net/docs/{0}.html".format(name))
 
     if type_ is not None:
-        attributes['type'] = type_
+        attributes["type"] = type_
 
-        type_str = '{0}.{1}'.format(type_.__module__, type_.__name__)
-        docs.append('Return type: :class:`{0}`.'.format(type_str))
+        type_str = "{0}.{1}".format(type_.__module__, type_.__name__)
+        docs.append("Return type: :class:`{0}`.".format(type_str))
 
     if len(docs) != 0:
-        attributes['__doc__'] = '\n\n'.join(docs)
+        attributes["__doc__"] = "\n\n".join(docs)
 
     globals()[name] = type(name, (GenericFunction,), attributes)
-
-
-#
-# Define compiled versions for functions in SpatiaLite whose names don't have
-# the ST_ prefix.
-#
-
-
-_SQLITE_FUNCTIONS = {
-    "ST_GeomFromEWKT": "GeomFromEWKT",
-    "ST_GeomFromEWKB": "GeomFromEWKB",
-    "ST_AsBinary": "AsBinary",
-    "ST_AsEWKB": "AsEWKB",
-    "ST_AsGeoJSON": "AsGeoJSON",
-}
-
-
-# Default handlers are required for SQLAlchemy < 1.1
-# See more details in https://github.com/geoalchemy/geoalchemy2/issues/213
-def _compiles_default(cls):
-    def _compile_default(element, compiler, **kw):
-        return "{}({})".format(cls, compiler.process(element.clauses, **kw))
-    compiles(globals()[cls])(_compile_default)
-
-
-def _compiles_sqlite(cls, fn):
-    def _compile_sqlite(element, compiler, **kw):
-        return "{}({})".format(fn, compiler.process(element.clauses, **kw))
-    compiles(globals()[cls], "sqlite")(_compile_sqlite)
-
-
-def register_sqlite_mapping(mapping):
-    """Register compilation mappings for the given functions.
-
-    Args:
-        mapping: Should have the following form::
-
-                {
-                    "function_name_1": "sqlite_function_name_1",
-                    "function_name_2": "sqlite_function_name_2",
-                    ...
-                }
-    """
-    for cls, fn in mapping.items():
-        _compiles_default(cls)
-        _compiles_sqlite(cls, fn)
-
-
-register_sqlite_mapping(_SQLITE_FUNCTIONS)
