@@ -19,7 +19,6 @@ from geoalchemy2.shape import to_shape
 
 # Tests imports
 from tests import select
-from tests import test_only_with_dialects
 
 metadata = MetaData()
 
@@ -32,9 +31,7 @@ table = Table(
 )
 
 
-@test_only_with_dialects("postgresql")
-class TestLengthAtInsert():
-
+class TestLengthAtInsert:
     def test_query(self, conn):
         metadata.drop_all(conn, checkfirst=True)
         metadata.create_all(conn)
@@ -42,11 +39,11 @@ class TestLengthAtInsert():
         # Define geometries to insert
         values = [
             {"ewkt": "SRID=4326;LINESTRING(0 0, 1 0)"},
-            {"ewkt": "SRID=4326;LINESTRING(0 0, 0 1)"}
+            {"ewkt": "SRID=4326;LINESTRING(0 0, 0 1)"},
         ]
 
         # Define the query to compute distance (without spheroid)
-        distance = func.ST_Length(func.ST_GeomFromText(bindparam("ewkt")), False)
+        distance = func.ST_Length(func.ST_GeomFromEWKT(bindparam("ewkt")), False)
 
         i = table.insert()
         i = i.values(geom=bindparam("ewkt"), distance=distance)
