@@ -1,6 +1,4 @@
 """Test alembic migrations of spatial columns."""
-import platform
-
 import pytest
 import sqlalchemy as sa  # noqa (This import is only used in the migration scripts)
 from alembic import command
@@ -12,6 +10,7 @@ from sqlalchemy import Column
 from sqlalchemy import Integer
 from sqlalchemy import MetaData
 from sqlalchemy import Table
+from sqlalchemy import text
 
 from geoalchemy2 import Geometry
 from geoalchemy2 import alembic_helpers
@@ -26,7 +25,7 @@ def filter_tables(name, type_, parent_names):
 
 
 class TestAutogenerate:
-    def test_no_diff(self, conn, Lake, setup_tables):
+    def test_no_diff(self, conn, Lake, setup_tables, use_sqlite_monkeypatch):
         """Check that the autogeneration detects spatial types properly."""
         metadata = MetaData()
 
@@ -57,7 +56,7 @@ class TestAutogenerate:
 
         assert diff == []
 
-    def test_diff(self, conn, Lake, setup_tables):
+    def test_diff(self, conn, Lake, setup_tables, use_sqlite_monkeypatch):
         """Check that the autogeneration detects spatial types properly."""
         metadata = MetaData()
 
@@ -141,11 +140,10 @@ def test_script_path(alembic_dir):
 
 
 @pytest.fixture
-def alembic_env(
-    engine, alembic_dir, alembic_config_path, alembic_env_path, test_script_path
-):
+def alembic_env(engine, alembic_dir, alembic_config_path, alembic_env_path, test_script_path):
     cfg_tmp = Config(alembic_config_path)
-    engine.execute("DROP TABLE IF EXISTS alembic_version;")
+    with engine.begin() as connection:
+        connection.execute(text("DROP TABLE IF EXISTS alembic_version;"))
     command.init(cfg_tmp, str(alembic_dir), template="generic")
     with alembic_env_path.open(mode="w", encoding="utf8") as f:
         f.write(
@@ -196,7 +194,7 @@ finally:
 
 """.format(
                 str(test_script_path),
-                True if engine.dialect.name == "sqlite" else False
+                True if engine.dialect.name == "sqlite" else False,
             )
         )
     with test_script_path.open(mode="w", encoding="utf8") as f:
@@ -247,7 +245,7 @@ format = %%(levelname)-5.5s [%%(name)s] %%(message)s
 datefmt = %%H:%%M:%%S
 
 """.format(
-                alembic_dir, engine.url
+                alembic_dir, str(engine.url).replace("***", engine.url.password or "")
             )
         )
     return cfg
@@ -255,11 +253,8 @@ datefmt = %%H:%%M:%%S
 
 @test_only_with_dialects("postgresql", "sqlite-spatialite4")
 def test_migration_revision(
-    conn, metadata, alembic_config, alembic_env_path, test_script_path
+    conn, metadata, alembic_config, alembic_env_path, test_script_path, use_sqlite_monkeypatch
 ):
-    if platform.python_implementation().lower() == 'pypy':
-        pytest.skip('skip SpatiaLite tests on PyPy', allow_module_level=True)
-
     initial_rev = command.revision(
         alembic_config,
         "Initial state",
@@ -362,7 +357,8 @@ new_table = Table(
     # Insert data in new table to check that everything works when Alembic copies the tables
     from_text = "GeomFromEWKT" if conn.dialect.name == "sqlite" else "ST_GeomFromEWKT"
     conn.execute(
-        """INSERT INTO new_spatial_table (
+        text(
+            """INSERT INTO new_spatial_table (
             geom_with_idx,
             geom_without_idx,
             geom_without_idx_2
@@ -372,10 +368,11 @@ new_table = Table(
             {from_text}('SRID=4326;LINESTRING(0 0, 1 1)')
         )
         """.format(
-            from_text=from_text
+                from_text=from_text
+            )
         )
     )
-    conn.execute("COMMIT")
+    conn.execute(text("COMMIT"))
 
     # Remove spatial columns and add new ones
     with test_script_path.open(mode="w", encoding="utf8") as f:
