@@ -19,72 +19,72 @@ from geoalchemy2.types import Geometry
 
 @pytest.fixture
 def geometry_table():
-    table = Table('table', MetaData(), Column('geom', Geometry))
+    table = Table("table", MetaData(), Column("geom", Geometry))
     return table
 
 
 def eq_sql(a, b):
-    a = re.sub(r'[\n\t]', '', str(a))
+    a = re.sub(r"[\n\t]", "", str(a))
     assert a == b
 
 
-class TestWKTElement():
-
+class TestWKTElement:
     def test_desc(self):
-        e = WKTElement('POINT(1 2)')
-        assert e.desc == 'POINT(1 2)'
+        e = WKTElement("POINT(1 2)")
+        assert e.desc == "POINT(1 2)"
 
     def test_function_call(self):
-        e = WKTElement('POINT(1 2)')
+        e = WKTElement("POINT(1 2)")
         f = e.ST_Buffer(2)
-        eq_sql(f, 'ST_Buffer('
-               'ST_GeomFromText(:ST_GeomFromText_1, :ST_GeomFromText_2), '
-               ':ST_Buffer_1)')
+        eq_sql(
+            f,
+            "ST_Buffer("
+            "ST_GeomFromText(:ST_GeomFromText_1, :ST_GeomFromText_2), "
+            ":ST_Buffer_1)",
+        )
         assert f.compile().params == {
-            u'ST_Buffer_1': 2,
-            u'ST_GeomFromText_1': 'POINT(1 2)',
-            u'ST_GeomFromText_2': -1
+            "ST_Buffer_1": 2,
+            "ST_GeomFromText_1": "POINT(1 2)",
+            "ST_GeomFromText_2": -1,
         }
 
     def test_attribute_error(self):
-        e = WKTElement('POINT(1 2)')
-        assert not hasattr(e, 'foo')
+        e = WKTElement("POINT(1 2)")
+        assert not hasattr(e, "foo")
 
     def test_pickle_unpickle(self):
         import pickle
-        e = WKTElement('POINT(1 2)', srid=3, extended=True)
+
+        e = WKTElement("POINT(1 2)", srid=3, extended=True)
         pickled = pickle.dumps(e)
         unpickled = pickle.loads(pickled)
         assert unpickled.srid == 3
         assert unpickled.extended is True
-        assert unpickled.data == 'POINT(1 2)'
+        assert unpickled.data == "POINT(1 2)"
         f = unpickled.ST_Buffer(2)
-        eq_sql(f, 'ST_Buffer('
-               'ST_GeomFromEWKT(:ST_GeomFromEWKT_1), '
-               ':ST_Buffer_1)')
+        eq_sql(f, "ST_Buffer(" "ST_GeomFromEWKT(:ST_GeomFromEWKT_1), " ":ST_Buffer_1)")
         assert f.compile().params == {
-            u'ST_Buffer_1': 2,
-            u'ST_GeomFromEWKT_1': 'POINT(1 2)',
+            "ST_Buffer_1": 2,
+            "ST_GeomFromEWKT_1": "POINT(1 2)",
         }
 
     def test_eq(self):
-        a = WKTElement('POINT(1 2)')
-        b = WKTElement('POINT(1 2)')
+        a = WKTElement("POINT(1 2)")
+        b = WKTElement("POINT(1 2)")
         assert a == b
 
     def test_hash(self):
-        a = WKTElement('POINT(1 2)')
-        b = WKTElement('POINT(10 20)')
-        c = WKTElement('POINT(10 20)')
+        a = WKTElement("POINT(1 2)")
+        b = WKTElement("POINT(10 20)")
+        c = WKTElement("POINT(10 20)")
         assert set([a, b, c]) == set([a, b, c])
         assert len(set([a, b, c])) == 2
 
 
-class TestExtendedWKTElement():
-
+class TestExtendedWKTElement:
     _srid = 3857  # expected srid
-    _wkt = 'POINT (1 2 3)'  # expected wkt
-    _ewkt = 'SRID=3857;POINT (1 2 3)'  # expected ewkt
+    _wkt = "POINT (1 2 3)"  # expected wkt
+    _ewkt = "SRID=3857;POINT (1 2 3)"  # expected ewkt
 
     def test_desc(self):
         e = WKTElement(self._ewkt, extended=True)
@@ -93,16 +93,12 @@ class TestExtendedWKTElement():
     def test_function_call(self):
         e = WKTElement(self._ewkt, extended=True)
         f = e.ST_Buffer(2)
-        eq_sql(f, 'ST_Buffer('
-               'ST_GeomFromEWKT(:ST_GeomFromEWKT_1), '
-               ':ST_Buffer_1)')
-        assert f.compile().params == {
-            u'ST_Buffer_1': 2,
-            u'ST_GeomFromEWKT_1': self._ewkt
-        }
+        eq_sql(f, "ST_Buffer(" "ST_GeomFromEWKT(:ST_GeomFromEWKT_1), " ":ST_Buffer_1)")
+        assert f.compile().params == {"ST_Buffer_1": 2, "ST_GeomFromEWKT_1": self._ewkt}
 
     def test_pickle_unpickle(self):
         import pickle
+
         e = WKTElement(self._ewkt, extended=True)
         pickled = pickle.dumps(e)
         unpickled = pickle.loads(pickled)
@@ -110,12 +106,10 @@ class TestExtendedWKTElement():
         assert unpickled.extended is True
         assert unpickled.data == self._ewkt
         f = unpickled.ST_Buffer(2)
-        eq_sql(f, 'ST_Buffer('
-               'ST_GeomFromEWKT(:ST_GeomFromEWKT_1), '
-               ':ST_Buffer_1)')
+        eq_sql(f, "ST_Buffer(" "ST_GeomFromEWKT(:ST_GeomFromEWKT_1), " ":ST_Buffer_1)")
         assert f.compile().params == {
-            u'ST_Buffer_1': 2,
-            u'ST_GeomFromEWKT_1': self._ewkt,
+            "ST_Buffer_1": 2,
+            "ST_GeomFromEWKT_1": self._ewkt,
         }
 
     def test_unpack_srid_from_ewkt(self):
@@ -134,7 +128,7 @@ class TestExtendedWKTElement():
 
     def test_unpack_srid_from_bad_ewkt(self):
         with pytest.raises(ArgumentError):
-            WKTElement('SRID=BAD SRID;POINT (1 2 3)', extended=True)
+            WKTElement("SRID=BAD SRID;POINT (1 2 3)", extended=True)
 
     def test_eq(self):
         a = WKTElement(self._ewkt, extended=True)
@@ -142,9 +136,9 @@ class TestExtendedWKTElement():
         assert a == b
 
     def test_hash(self):
-        a = WKTElement('SRID=3857;POINT (1 2 3)', extended=True)
-        b = WKTElement('SRID=3857;POINT (10 20 30)', extended=True)
-        c = WKTElement('SRID=3857;POINT (10 20 30)', extended=True)
+        a = WKTElement("SRID=3857;POINT (1 2 3)", extended=True)
+        b = WKTElement("SRID=3857;POINT (10 20 30)", extended=True)
+        c = WKTElement("SRID=3857;POINT (10 20 30)", extended=True)
         assert set([a, b, c]) == set([a, b, c])
         assert len(set([a, b, c])) == 2
 
@@ -157,68 +151,71 @@ class TestExtendedWKTElement():
             WKTElement("SRID=3857" + self._wkt, extended=True)
 
 
-class TestWKTElementFunction():
-
+class TestWKTElementFunction:
     def test_ST_Equal_WKTElement_WKTElement(self):
-        expr = func.ST_Equals(WKTElement('POINT(1 2)'),
-                              WKTElement('POINT(1 2)'))
-        eq_sql(expr, 'ST_Equals('
-               'ST_GeomFromText(:ST_GeomFromText_1, :ST_GeomFromText_2), '
-               'ST_GeomFromText(:ST_GeomFromText_3, :ST_GeomFromText_4))')
+        expr = func.ST_Equals(WKTElement("POINT(1 2)"), WKTElement("POINT(1 2)"))
+        eq_sql(
+            expr,
+            "ST_Equals("
+            "ST_GeomFromText(:ST_GeomFromText_1, :ST_GeomFromText_2), "
+            "ST_GeomFromText(:ST_GeomFromText_3, :ST_GeomFromText_4))",
+        )
         assert expr.compile().params == {
-            u'ST_GeomFromText_1': 'POINT(1 2)',
-            u'ST_GeomFromText_2': -1,
-            u'ST_GeomFromText_3': 'POINT(1 2)',
-            u'ST_GeomFromText_4': -1,
+            "ST_GeomFromText_1": "POINT(1 2)",
+            "ST_GeomFromText_2": -1,
+            "ST_GeomFromText_3": "POINT(1 2)",
+            "ST_GeomFromText_4": -1,
         }
 
     def test_ST_Equal_Column_WKTElement(self, geometry_table):
-        expr = func.ST_Equals(geometry_table.c.geom, WKTElement('POINT(1 2)'))
-        eq_sql(expr,
-               'ST_Equals("table".geom, '
-               'ST_GeomFromText(:ST_GeomFromText_1, :ST_GeomFromText_2))')
+        expr = func.ST_Equals(geometry_table.c.geom, WKTElement("POINT(1 2)"))
+        eq_sql(
+            expr,
+            'ST_Equals("table".geom, ' "ST_GeomFromText(:ST_GeomFromText_1, :ST_GeomFromText_2))",
+        )
         assert expr.compile().params == {
-            u'ST_GeomFromText_1': 'POINT(1 2)',
-            u'ST_GeomFromText_2': -1
+            "ST_GeomFromText_1": "POINT(1 2)",
+            "ST_GeomFromText_2": -1,
         }
 
 
-class TestExtendedWKTElementFunction():
-
+class TestExtendedWKTElementFunction:
     def test_ST_Equal_WKTElement_WKTElement(self):
-        expr = func.ST_Equals(WKTElement('SRID=3857;POINT(1 2 3)',
-                                         extended=True),
-                              WKTElement('SRID=3857;POINT(1 2 3)',
-                                         extended=True))
-        eq_sql(expr, 'ST_Equals('
-               'ST_GeomFromEWKT(:ST_GeomFromEWKT_1), '
-               'ST_GeomFromEWKT(:ST_GeomFromEWKT_2))')
+        expr = func.ST_Equals(
+            WKTElement("SRID=3857;POINT(1 2 3)", extended=True),
+            WKTElement("SRID=3857;POINT(1 2 3)", extended=True),
+        )
+        eq_sql(
+            expr,
+            "ST_Equals("
+            "ST_GeomFromEWKT(:ST_GeomFromEWKT_1), "
+            "ST_GeomFromEWKT(:ST_GeomFromEWKT_2))",
+        )
         assert expr.compile().params == {
-            u'ST_GeomFromEWKT_1': 'SRID=3857;POINT(1 2 3)',
-            u'ST_GeomFromEWKT_2': 'SRID=3857;POINT(1 2 3)',
+            "ST_GeomFromEWKT_1": "SRID=3857;POINT(1 2 3)",
+            "ST_GeomFromEWKT_2": "SRID=3857;POINT(1 2 3)",
         }
 
     def test_ST_Equal_Column_WKTElement(self, geometry_table):
-        expr = func.ST_Equals(geometry_table.c.geom,
-                              WKTElement('SRID=3857;POINT(1 2 3)',
-                                         extended=True))
-        eq_sql(expr,
-               'ST_Equals("table".geom, '
-               'ST_GeomFromEWKT(:ST_GeomFromEWKT_1))')
+        expr = func.ST_Equals(
+            geometry_table.c.geom, WKTElement("SRID=3857;POINT(1 2 3)", extended=True)
+        )
+        eq_sql(expr, 'ST_Equals("table".geom, ' "ST_GeomFromEWKT(:ST_GeomFromEWKT_1))")
         assert expr.compile().params == {
-            u'ST_GeomFromEWKT_1': 'SRID=3857;POINT(1 2 3)',
+            "ST_GeomFromEWKT_1": "SRID=3857;POINT(1 2 3)",
         }
 
 
-class TestExtendedWKBElement():
-
+class TestExtendedWKBElement:
     # _bin/_hex computed by following query:
     # SELECT ST_GeomFromEWKT('SRID=3;POINT(1 2)');
-    _bin = memoryview(b'\x01\x01\x00\x00 \x03\x00\x00\x00\x00\x00\x00'
-                      b'\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@')
-    _hex = str('010100002003000000000000000000f03f0000000000000040')
+    _bin = memoryview(
+        b"\x01\x01\x00\x00 \x03\x00\x00\x00\x00\x00\x00"
+        b"\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@"
+    )
+    _hex = str("010100002003000000000000000000f03f0000000000000040")
     _srid = 3  # expected srid
-    _wkt = 'POINT (1 2)'  # expected wkt
+    _wkt = "POINT (1 2)"  # expected wkt
 
     def test_desc(self):
         e = WKBElement(self._bin, extended=True)
@@ -231,12 +228,10 @@ class TestExtendedWKBElement():
     def test_function_call(self):
         e = WKBElement(self._bin, extended=True)
         f = e.ST_Buffer(2)
-        eq_sql(f, 'ST_Buffer('
-               'ST_GeomFromEWKB(:ST_GeomFromEWKB_1), '
-               ':ST_Buffer_1)')
+        eq_sql(f, "ST_Buffer(" "ST_GeomFromEWKB(:ST_GeomFromEWKB_1), " ":ST_Buffer_1)")
         assert f.compile().params == {
-            u'ST_Buffer_1': 2,
-            u'ST_GeomFromEWKB_1': self._bin,
+            "ST_Buffer_1": 2,
+            "ST_GeomFromEWKB_1": self._bin,
         }
 
     def test_function_str(self):
@@ -245,6 +240,7 @@ class TestExtendedWKBElement():
 
     def test_pickle_unpickle(self):
         import pickle
+
         e = WKBElement(self._bin, srid=self._srid, extended=True)
         pickled = pickle.dumps(e)
         unpickled = pickle.loads(pickled)
@@ -252,12 +248,10 @@ class TestExtendedWKBElement():
         assert unpickled.extended is True
         assert unpickled.data == bytes(self._bin)
         f = unpickled.ST_Buffer(2)
-        eq_sql(f, 'ST_Buffer('
-               'ST_GeomFromEWKB(:ST_GeomFromEWKB_1), '
-               ':ST_Buffer_1)')
+        eq_sql(f, "ST_Buffer(" "ST_GeomFromEWKB(:ST_GeomFromEWKB_1), " ":ST_Buffer_1)")
         assert f.compile().params == {
-            u'ST_Buffer_1': 2,
-            u'ST_GeomFromEWKB_1': bytes(self._bin),
+            "ST_Buffer_1": 2,
+            "ST_GeomFromEWKB_1": bytes(self._bin),
         }
 
     def test_unpack_srid_from_bin(self):
@@ -285,62 +279,64 @@ class TestExtendedWKBElement():
         assert a == b
 
     def test_hash(self):
-        a = WKBElement(str('010100002003000000000000000000f03f0000000000000040'), extended=True)
-        b = WKBElement(str('010100002003000000000000000000f02f0000000000000040'), extended=True)
-        c = WKBElement(str('010100002003000000000000000000f02f0000000000000040'), extended=True)
+        a = WKBElement(str("010100002003000000000000000000f03f0000000000000040"), extended=True)
+        b = WKBElement(str("010100002003000000000000000000f02f0000000000000040"), extended=True)
+        c = WKBElement(str("010100002003000000000000000000f02f0000000000000040"), extended=True)
         assert set([a, b, c]) == set([a, b, c])
         assert len(set([a, b, c])) == 2
 
 
-class TestWKBElement():
-
+class TestWKBElement:
     def test_desc(self):
-        e = WKBElement(b'\x01\x02')
-        assert e.desc == '0102'
+        e = WKBElement(b"\x01\x02")
+        assert e.desc == "0102"
 
     def test_function_call(self):
-        e = WKBElement(b'\x01\x02')
+        e = WKBElement(b"\x01\x02")
         f = e.ST_Buffer(2)
-        eq_sql(f, 'ST_Buffer('
-               'ST_GeomFromWKB(:ST_GeomFromWKB_1, :ST_GeomFromWKB_2), '
-               ':ST_Buffer_1)')
+        eq_sql(
+            f,
+            "ST_Buffer(" "ST_GeomFromWKB(:ST_GeomFromWKB_1, :ST_GeomFromWKB_2), " ":ST_Buffer_1)",
+        )
         assert f.compile().params == {
-            u'ST_Buffer_1': 2, u'ST_GeomFromWKB_1': b'\x01\x02',
-            u'ST_GeomFromWKB_2': -1
+            "ST_Buffer_1": 2,
+            "ST_GeomFromWKB_1": b"\x01\x02",
+            "ST_GeomFromWKB_2": -1,
         }
 
     def test_attribute_error(self):
-        e = WKBElement(b'\x01\x02')
-        assert not hasattr(e, 'foo')
+        e = WKBElement(b"\x01\x02")
+        assert not hasattr(e, "foo")
 
     def test_function_str(self):
-        e = WKBElement(b'\x01\x02')
+        e = WKBElement(b"\x01\x02")
         assert isinstance(str(e), str)
 
     def test_eq(self):
-        a = WKBElement(b'\x01\x02')
-        b = WKBElement(b'\x01\x02')
+        a = WKBElement(b"\x01\x02")
+        b = WKBElement(b"\x01\x02")
         assert a == b
 
     def test_hash(self):
-        a = WKBElement(b'\x01\x02')
-        b = WKBElement(b'\x01\x03')
-        c = WKBElement(b'\x01\x03')
+        a = WKBElement(b"\x01\x02")
+        b = WKBElement(b"\x01\x03")
+        c = WKBElement(b"\x01\x03")
         assert set([a, b, c]) == set([a, b, c])
         assert len(set([a, b, c])) == 2
 
 
-class TestNotEqualSpatialElement():
-
+class TestNotEqualSpatialElement:
     # _bin/_hex computed by following query:
     # SELECT ST_GeomFromEWKT('SRID=3;POINT(1 2)');
-    _ewkb = memoryview(b'\x01\x01\x00\x00 \x03\x00\x00\x00\x00\x00\x00'
-                       b'\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@')
+    _ewkb = memoryview(
+        b"\x01\x01\x00\x00 \x03\x00\x00\x00\x00\x00\x00"
+        b"\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@"
+    )
     _wkb = wkb.loads(bytes(_ewkb)).wkb
-    _hex = str('010100002003000000000000000000f03f0000000000000040')
+    _hex = str("010100002003000000000000000000f03f0000000000000040")
     _srid = 3
-    _wkt = 'POINT (1 2)'
-    _ewkt = 'SRID=3;POINT (1 2)'
+    _wkt = "POINT (1 2)"
+    _ewkt = "SRID=3;POINT (1 2)"
 
     def test_eq(self):
         a = WKBElement(self._ewkb, extended=True)
@@ -368,19 +364,20 @@ class TestNotEqualSpatialElement():
             assert i != e and e != i
 
 
-class TestRasterElement():
-
+class TestRasterElement:
     rast_data = (
-        b'\x01\x00\x00\x01\x00\x9a\x99\x99\x99\x99\x99\xc9?\x9a\x99\x99\x99\x99\x99'
-        b'\xc9\xbf\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xf0?\x00'
-        b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xe6\x10\x00'
-        b'\x00\x05\x00\x05\x00D\x00\x01\x01\x01\x01\x01\x01\x01\x01\x01\x00\x01\x01'
-        b'\x01\x00\x00\x01\x01\x00\x00\x00\x01\x00\x00\x00\x00')
+        b"\x01\x00\x00\x01\x00\x9a\x99\x99\x99\x99\x99\xc9?\x9a\x99\x99\x99\x99\x99"
+        b"\xc9\xbf\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xf0?\x00"
+        b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xe6\x10\x00"
+        b"\x00\x05\x00\x05\x00D\x00\x01\x01\x01\x01\x01\x01\x01\x01\x01\x00\x01\x01"
+        b"\x01\x00\x00\x01\x01\x00\x00\x00\x01\x00\x00\x00\x00"
+    )
 
     hex_rast_data = (
-        '01000001009a9999999999c93f9a9999999999c9bf0000000000000000000000000000f03'
-        'f00000000000000000000000000000000e610000005000500440001010101010101010100'
-        '010101000001010000000100000000')
+        "01000001009a9999999999c93f9a9999999999c9bf0000000000000000000000000000f03"
+        "f00000000000000000000000000000000e610000005000500440001010101010101010100"
+        "010101000001010000000100000000"
+    )
 
     def test_desc(self):
         e = RasterElement(self.rast_data)
@@ -393,11 +390,12 @@ class TestRasterElement():
     def test_function_call(self):
         e = RasterElement(self.rast_data)
         f = e.ST_Height()
-        eq_sql(f, 'ST_Height(raster(:raster_1))')
-        assert f.compile().params == {u'raster_1': self.hex_rast_data}
+        eq_sql(f, "ST_Height(raster(:raster_1))")
+        assert f.compile().params == {"raster_1": self.hex_rast_data}
 
     def test_pickle_unpickle(self):
         import pickle
+
         e = RasterElement(self.rast_data)
         assert e.srid == 4326
         assert e.extended is True
@@ -408,13 +406,13 @@ class TestRasterElement():
         assert unpickled.extended is True
         assert unpickled.data == self.hex_rast_data
         f = unpickled.ST_Height()
-        eq_sql(f, 'ST_Height(raster(:raster_1))')
+        eq_sql(f, "ST_Height(raster(:raster_1))")
         assert f.compile().params == {
-            u'raster_1': self.hex_rast_data,
+            "raster_1": self.hex_rast_data,
         }
 
     def test_hash(self):
-        new_hex_rast_data = self.hex_rast_data.replace('f', 'e')
+        new_hex_rast_data = self.hex_rast_data.replace("f", "e")
         a = WKBElement(self.hex_rast_data)
         b = WKBElement(new_hex_rast_data)
         c = WKBElement(new_hex_rast_data)
@@ -422,12 +420,11 @@ class TestRasterElement():
         assert len(set([a, b, c])) == 2
 
 
-class TestCompositeElement():
-
+class TestCompositeElement:
     def test_compile(self):
         # text fixture
         metadata = MetaData()
-        foo = Table('foo', metadata, Column('one', String))
+        foo = Table("foo", metadata, Column("one", String))
 
-        e = CompositeElement(foo.c.one, 'geom', String)
-        assert str(e) == '(foo.one).geom'
+        e = CompositeElement(foo.c.one, "geom", String)
+        assert str(e) == "(foo.one).geom"
